@@ -319,7 +319,7 @@ glibtop_get_sem_limits_l (glibtop *server, glibtop_sem_limits *buf)
 					  &server->required.sem_limits);
 }
 
-unsigned *
+pid_t*
 glibtop_get_proclist_l (glibtop *server, glibtop_proclist *buf,
                         gint64 which, gint64 arg)
 {
@@ -330,7 +330,7 @@ glibtop_get_proclist_l (glibtop *server, glibtop_proclist *buf,
 
 	const void *send_ptr = &param_buf;
 	const size_t send_size = sizeof param_buf;
-	unsigned * retval = (unsigned *) 0;
+	pid_t* retval = (pid_t*) 0;
 	param_buf.buf_which = which;
 	param_buf.buf_arg = arg;
 
