@@ -1,5 +1,3 @@
-/* $Id: netload.c,v 1.9 2005/12/12 09:38:12 jamesh Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -31,7 +29,7 @@ static const unsigned long _glibtop_sysdeps_netload = 0;
 /* Init function. */
 
 void
-glibtop_init_netload_p (glibtop *server)
+_glibtop_init_netload_p (glibtop *server)
 {
 	server->sysdeps.netload = _glibtop_sysdeps_netload;
 }
